@@ -24,8 +24,8 @@ public:
     void setInvalidFilters(const QList<InvalidFilterInfo> &lst);
 
 private:
-    void writeConfig();
-    void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
+    MAILCOMMON_NO_EXPORT void readConfig();
     InvalidFilterWidget *const mInvalidFilterWidget;
     InvalidFilterInfoWidget *const mInvalidFilterInfoWidget;
 };
